@@ -324,7 +324,7 @@ class VariableClAutologin(UserHelper, Variable):
 
     def init(self):
         self.label = _("Autologin")
-        self.help = _("add an autologin user to the installed system")
+        self.help = _("add an autologin user to the installed system, 'off' for disable autologin")
 
     def get(self):
         # autologin enable for livecd and all install type CMC
@@ -344,10 +344,14 @@ class VariableClAutologin(UserHelper, Variable):
         return ""
 
     def set(self, value):
-        return {'none': ''}.get(value, value)
+        return {'none': '',
+                'off': ''}.get(value, value)
 
     def choice(self):
-        return [""] + filter(lambda x: x != "root", self.Get('cl_migrate_user'))
+        yield ("off", _("No autologin"))
+        for user in (x for x in self.Get('cl_migrate_user')
+                     if x != "root"):
+            yield (user,user)
 
     def check(self, value):
         """
